These are the most important concepts and definitions used throughout this documentation.

## Action

An action is, in its most basic terms, something you can do with your bot. You are in charge of defining them.

## Command

A command is a string sent to your bot through Telegram that executes an action. They are always prefixed with a slash (for example, `/start` or `/hello`). 

!!! info
    An action may have many commands assigned.
